# 工具集

## aliyun
阿里云相关功能方法
> 1.杭州ingress日志查询方法  hz_ingress_log
> 1.杭州service日志查询方法  hz_service_log
> 2.硅谷ingress日志查询方法  usa_ingress_log
> 2.硅谷service日志查询方法  usa_service_log

## excel
excel相关功能方法
> 1.将字典列表写入excel中 list_write_excel

## qw
企业微信
> 1.markdown格式的企业微信通知 send_markdown_message

## command
subprocess执行shell命令
> 1.通过subprocess执行shell命令 exec_command
> 2.通过subprocess执行shell命令支持实时输出 exec_command_realtime_output

## domain
域名相关功能方法
> 1.获取域名解析的IP地址 get_ip_list
> 2.获取域名解析的证书及过期天数 get_cert_details

## sql
执行mysql相关的sql
> 1.执行sql exec_mysql